@@ -24,7 +24,7 @@ log.setLevel('CRITICAL')
 
 class PointSet(Common):
     """PyVista's equivalent of vtk.vtkPointSet.
-    
+
     This holds methods common to PolyData and UnstructuredGrid.
     """
 
@@ -56,6 +56,44 @@ class PointSet(Common):
             to_copy.SetPoints(vtk.vtkPoints())
         return Common.shallow_copy(self, to_copy)
 
+    def remove_cells(self, ind, inplace=True):
+        """Remove cells.
+
+        Parameters
+        ----------
+        ind : iterable
+            Cell indices to be removed.  The array can also be a
+            boolean array of the same size as the number of cells.
+
+        inplace : bool, optional
+            Updates mesh in-place while returning nothing when ``True``.
+
+        Examples
+        --------
+        Remove first 1000 cells from an unstructured grid.
+
+        >>> import pyvista
+        >>> letter_a = pyvista.examples.download_letter_a()
+        >>> letter_a.remove_cells(range(1000))
+        """
+        if isinstance(ind, np.ndarray):
+            if ind.dtype == np.bool and ind.size != self.n_cells:
+                raise ValueError('Boolean array size must match the '
+                                 'number of cells (%d)' % self.n_cells)
+        ghost_cells = np.zeros(self.n_cells, np.uint8)
+        ghost_cells[ind] = vtk.vtkDataSetAttributes.DUPLICATECELL
+
+        if inplace:
+            target = self
+        else:
+            target = self.copy()
+
+        target.cell_arrays[vtk.vtkDataSetAttributes.GhostArrayName()] = ghost_cells
+        target.RemoveGhostCells()
+
+        if not inplace:
+            return target
+
 
 class PolyData(vtkPolyData, PointSet, PolyDataFilters):
     """Extend the functionality of a vtk.vtkPolyData object.
@@ -132,7 +170,7 @@ class PolyData(vtkPolyData, PointSet, PolyDataFilters):
         # Check if need to make vertex cells
         if self.n_points > 0 and self.n_cells == 0:
             # make vertex cells
-            self.faces = self._make_vertice_cells(self.n_points)
+            self.verts = self._make_vertice_cells(self.n_points)
 
     def __repr__(self):
         """Return the standard representation."""
@@ -197,6 +235,35 @@ class PolyData(vtkPolyData, PointSet, PolyDataFilters):
         if not np.any(self.points):
             raise AssertionError('Empty or invalid file')
 
+    @property
+    def verts(self):
+        """Get the vertice cells."""
+        return vtk_to_numpy(self.GetVerts().GetData())
+
+    @verts.setter
+    def verts(self, verts):
+        """Set the vertice cells."""
+        if not isinstance(verts, np.ndarray):
+            verts = np.asarray(verts)
+
+        if verts.dtype != pyvista.ID_TYPE:
+            verts = verts.astype(pyvista.ID_TYPE)
+
+        # get number of verts
+        if verts.ndim == 1:
+            log.debug('efficiency warning')
+            c = 0
+            nverts = 0
+            while c < verts.size:
+                c += verts[c] + 1
+                nverts += 1
+        else:
+            nverts = verts.shape[0]
+
+        vtkcells = vtk.vtkCellArray()
+        vtkcells.SetCells(nverts, numpy_to_vtkIdTypeArray(verts, deep=False))
+        self.SetVerts(vtkcells)
+
     @property
     def lines(self):
         """Return a pointer to the lines as a numpy object."""
@@ -344,7 +411,7 @@ class PolyData(vtkPolyData, PointSet, PolyDataFilters):
         """Write a surface mesh to disk.
 
         Written file may be an ASCII or binary ply, stl, or vtk mesh
-        file. If ply or stl format is chosen, the face normals are 
+        file. If ply or stl format is chosen, the face normals are
         computed in place to ensure the mesh is properly saved.
 
         Parameters
@@ -772,7 +839,7 @@ class UnstructuredGrid(vtkUnstructuredGrid, PointGrid, UnstructuredGridFilters):
 
     def linear_copy(self, deep=False):
         """Return a copy of the unstructured grid containing only linear cells.
-        
+
         Converts the following cell types to their linear equivalents.
 
         - VTK_QUADRATIC_TETRA      --> VTK_TETRA
@@ -1054,3 +1121,43 @@ class StructuredGrid(vtkStructuredGrid, PointGrid):
         attrs = PointGrid._get_attrs(self)
         attrs.append(("Dimensions", self.dimensions, "{:d}, {:d}, {:d}"))
         return attrs
+
+    def hide_cells(self, ind):
+        """Hide cells without deleting them.
+
+        Hides cells by setting the ghost_cells array to HIDDEN_CELL.
+
+        Parameters
+        ----------
+        ind : iterable
+            List or array of cell indices to be hidden.  The array can
+            also be a boolean array of the same size as the number of
+            cells.
+
+        Examples
+        --------
+        Hide part of the middle of a structured surface.
+
+        >>> import pyvista as pv
+        >>> import numpy as np
+        >>> x = np.arange(-10, 10, 0.25)
+        >>> y = np.arange(-10, 10, 0.25)
+        >>> z = 0
+        >>> x, y, z = np.meshgrid(x, y, z)
+        >>> grid = pv.StructuredGrid(x, y, z)
+        >>> grid.hide_cells(range(79*30, 79*50))
+        """
+        if isinstance(ind, np.ndarray):
+            if ind.dtype == np.bool and ind.size != self.n_cells:
+                raise ValueError('Boolean array size must match the '
+                                 'number of cells (%d)' % self.n_cells)
+        ghost_cells = np.zeros(self.n_cells, np.uint8)
+        ghost_cells[ind] = vtk.vtkDataSetAttributes.HIDDENCELL
+
+        # NOTE: cells cannot be removed from a structured grid, only
+        # hidden setting ghost_cells to a value besides
+        # vtk.vtkDataSetAttributes.HIDDENCELL will not hide them
+        # properly, additionally, calling self.RemoveGhostCells will
+        # have no effect
+
+        self.cell_arrays[vtk.vtkDataSetAttributes.GhostArrayName()] = ghost_cells
