@@ -442,7 +442,8 @@ class QtInteractor(QVTKRenderWindowInteractorAdapter, BasePlotter):
 
             self.iren.Initialize()
 
-            self.iren.AddObserver("KeyPressEvent", self.key_press_event)
+            self._observers = {}    # Map of events to observers of self.iren
+            self._add_observer("KeyPressEvent", self.key_press_event)
 
         # Make the render timer but only activate if using auto update
         self.render_timer = QTimer(parent=parent)
@@ -566,7 +567,10 @@ class QtInteractor(QVTKRenderWindowInteractorAdapter, BasePlotter):
 
     def close(self):
         """Quit application."""
-        self.render_timer.stop()
+        if self._closed:
+            return
+        if hasattr(self, "render_timer"):
+            self.render_timer.stop()
         BasePlotter.close(self)
         QVTKRenderWindowInteractorAdapter.close(self)
 
@@ -757,12 +761,11 @@ class BackgroundPlotter(QtInteractor):
         close the plotter through `signal_close`.
 
         """
-        self.app_window.close()
+        if not self._closed:
+            self.app_window.close()
 
     def _close(self):
-        if hasattr(self, "render_timer"):
-            self.render_timer.stop()
-        BasePlotter.close(self)
+        super().close()
 
     def update_app_icon(self):
         """Update the app icon if the user is not trying to resize the window."""
