@@ -1,8 +1,8 @@
 """Utilities routines."""
+from .errors import (GPUInfo, Observer, Report,
+                     assert_empty_kwargs, get_gpu_info, send_errors_to_logging,
+                     set_error_output_file, check_valid_vector)
 
-from .errors import (GPUInfo, Observer, Report, assert_empty_kwargs,
-                     get_gpu_info, send_errors_to_logging,
-                     set_error_output_file)
 from .features import *
 from .fileio import *
 from .geometric_objects import *
