@@ -17,7 +17,7 @@ import numpy as np
 import vtk
 
 import pyvista
-from pyvista.utilities import assert_empty_kwargs
+from pyvista.utilities import assert_empty_kwargs, check_valid_vector
 
 
 NORMALS = {
@@ -90,7 +90,6 @@ def Cylinder(center=(0.,0.,0.), direction=(1.,0.,0.), radius=0.5, height=1.0,
     >>> import numpy as np
     >>> cylinder = pyvista.Cylinder(np.array([1, 2, 3]), np.array([1, 1, 1]), 1, 1)
     >>> cylinder.plot() # doctest:+SKIP
-
     """
     capping = kwargs.pop('cap_ends', capping)
     assert_empty_kwargs(**kwargs)
@@ -296,7 +295,7 @@ def Plane(center=(0, 0, 0), direction=(0, 0, 1), i_size=1, j_size=1,
         Size of the plane in the i direction.
 
     j_size : float
-        Size of the plane in the i direction.
+        Size of the plane in the j direction.
 
     i_resolution : int
         Number of points on the plane in the i direction.
@@ -580,3 +579,101 @@ def Wavelet(extent=(-10,10,-10,10,-10,10), center=(0,0,0), maximum=255,
     wavelet_source.SetSubsampleRate(subsample_rate)
     wavelet_source.Update()
     return pyvista.wrap(wavelet_source.GetOutput())
+
+
+def CircularArc(pointa, pointb, center, resolution=100, normal=None,
+                polar=None, angle=None, negative=False):
+    """Create a circular arc defined by two endpoints and a center.
+
+    The number of segments composing the polyline is controlled by
+    setting the object resolution.  Alternatively, one can use a
+    better API (that does not allow for inconsistent nor ambiguous
+    inputs), using a starting point (polar vector, measured from the
+    arc's center), a normal to the plane of the arc, and an angle
+    defining the arc length.
+
+    Parameters
+    ----------
+    pointa : np.ndarray or list
+        Position of the first end point.
+
+    pointb : np.ndarray or list
+        Position of the other end point.
+
+    center : np.ndarray or list
+        Center of the circle that defines the arc.
+
+    resolution : int, optional
+        The number of segments of the polyline that draws the arc.
+        Resolution of 1 will just create a line.
+
+    normal : np.ndarray or list
+        The normal vector to the plane of the arc.  By default it
+        points in the positive Z direction.
+
+    polar : np.ndarray or list
+        (starting point of the arc).  By default it is the unit vector
+        in the positive x direction. Note: This is only used when
+        normal has been input.
+
+    angle : float
+        Arc length (in degrees), beginning at the polar vector.  The
+        direction is counterclockwise by default; a negative value
+        draws the arc in the clockwise direction.  Note: This is only
+        used when normal has been input.
+
+    negative : bool, optional
+        By default the arc spans the shortest angular sector point1 and point2.
+
+        By setting this to true, the longest angular sector is used
+        instead (i.e. the negative coterminal angle to the shortest
+        one). This is only used when normal has not been input
+
+    Examples
+    --------
+    Quarter arc centered at the origin in the xy plane
+
+    >>> import pyvista
+    >>> arc = pyvista.CircularArc([-1, 0, 0], [0, 1, 0], [0, 0, 0])
+    >>> pl = pyvista.Plotter()
+    >>> _ = pl.add_mesh(arc, color='k', line_width=4)
+    >>> _ = pl.show_bounds(location='all')
+    >>> _ = pl.view_xy()
+    >>> pl.show() # doctest:+SKIP
+
+    Quarter arc centered at the origin in the xz plane
+
+    >>> arc = pyvista.CircularArc([-1, 0, 0], [1, 0, 0], [0, 0, 0], normal=[0, 0, 1])
+    >>> arc.plot() # doctest:+SKIP
+    """
+    check_valid_vector(pointa, 'pointa')
+    check_valid_vector(pointb, 'pointb')
+    check_valid_vector(center, 'center')
+
+    # fix half-arc bug: if a half arc travels directly through the
+    # center point, it becomes a line
+    pointb = list(pointb)
+    pointb[0] -= 1E-10
+    pointb[1] -= 1E-10
+
+    arc = vtk.vtkArcSource()
+    arc.SetPoint1(*pointa)
+    arc.SetPoint2(*pointb)
+    arc.SetCenter(*center)
+    arc.SetResolution(resolution)
+    arc.SetNegative(negative)
+
+    if normal is not None:
+        arc.UseNormalAndAngleOn()
+        check_valid_vector(normal, 'normal')
+        arc.SetNormal(*normal)
+
+        if polar is not None:
+            check_valid_vector(polar, 'polar')
+            arc.SetPolarVector(*polar)
+
+        if angle is not None:
+            arc.SetAngle(angle)
+
+    arc.Update()
+    return pyvista.wrap(arc.GetOutput())
